@@ -491,6 +491,42 @@ class Ecobee(object):
         except (ExpiredTokenError, InvalidTokenError) as err:
             raise err
 
+    def set_dehumidifier_mode(self, index: int, dehumidifier_mode: str) -> None:
+        """Sets the dehumidifier mode (on, off)."""
+        body = {
+            "selection": {
+                "selectionType": "thermostats",
+                "selectionMatch": self.thermostats[index]["identifier"],
+            },
+            "thermostat": {"settings": {"dehumidifierMode": dehumidifier_mode}},
+        }
+        log_msg_action = "set dehumidifier mode"
+
+        try:
+            self._request_with_refresh(
+                "POST", ECOBEE_ENDPOINT_THERMOSTAT, log_msg_action, body=body
+            )
+        except (ExpiredTokenError, InvalidTokenError) as err:
+            raise err
+
+    def set_dehumidifier_level(self, index: int, dehumidifier_level: int) -> None:
+        """Sets the dehumidification set point in percentage."""
+        body = {
+            "selection": {
+                "selectionType": "thermostats",
+                "selectionMatch": self.thermostats[index]["identifier"],
+            },
+            "thermostat": {"settings": {"dehumidifierLevel": dehumidifier_level}}
+        }
+        log_msg_action = "set dehumidifier level"
+
+        try:
+            self._request_with_refresh(
+                "POST", ECOBEE_ENDPOINT_THERMOSTAT, log_msg_action, body=body
+            )
+        except (ExpiredTokenError, InvalidTokenError) as err:
+            raise err
+
     def set_humidifier_mode(self, index: int, humidifier_mode: str) -> None:
         """Sets the humidifier mode (auto, off, manual)."""
         body = {
@@ -675,6 +711,68 @@ class Ecobee(object):
         except (ExpiredTokenError, InvalidTokenError) as err:
             raise err
 
+    def set_aux_cutover_threshold(self, index: int, threshold: int) -> None:
+        """Set the threshold for outdoor temp below which alt heat will be used."""
+        body = {
+            "selection": {
+                "selectionType": "thermostats",
+                "selectionMatch": self.thermostats[index]["identifier"],
+            },
+            "thermostat": {"settings": {"compressorProtectionMinTemp": int(threshold * 10)}},
+        }
+        log_msg_action = "set outdoor temp threshold for aux"
+
+        try:
+            self._request_with_refresh(
+                "POST", ECOBEE_ENDPOINT_THERMOSTAT, log_msg_action, body=body
+            )
+        except (ExpiredTokenError, InvalidTokenError) as err:
+            raise err
+
+    def update_climate_sensors(self, index: int, climate_name: str, sensor_names: list) -> None:
+        """Get current climate program."""
+        programs: dict = self.thermostats[index]["program"]
+        # Remove currentClimateRef key.
+        programs.pop("currentClimateRef", None)
+
+        for i, climate in enumerate(programs["climates"]):
+            if climate["name"] == climate_name:
+                climate_index = i
+        """Update climate sensors with sensor_names list."""
+        sensor_list = []
+        for name in sensor_names:
+            """Find the sensor id from the name."""
+            sensors = self.get_remote_sensors(index)
+            for sensor in sensors:
+                if sensor["name"] == name:
+                    sensor_list.append(
+                        {"id": "{}:1".format(sensor["id"]), "name": name})
+        try:
+            programs["climates"][climate_index]["sensors"] = sensor_list
+        except UnboundLocalError:
+            """This would occur if the climate_index was not assigned
+                because the climate name does not exist in the program climates."""
+            return
+
+        """Updates Climate"""
+        body = {
+            "selection": {
+                "selectionType": "thermostats",
+                "selectionMatch": self.thermostats[index]["identifier"],
+            },
+            "thermostat": {
+                "program": programs
+            }
+        }
+        log_msg_action = "upate climate sensors"
+
+        try:
+            self._request_with_refresh(
+                "POST", ECOBEE_ENDPOINT_THERMOSTAT, log_msg_action, body=body
+            )
+        except (ExpiredTokenError, InvalidTokenError) as err:
+            raise err
+
     def _request_with_refresh(
         self,
         method: str,
